[Libguestfs] [PATCH 2/2] rescue: Print chroot suggestion for Linux guests.

Richard W.M. Jones rjones at redhat.com
Thu Mar 24 10:48:32 UTC 2016


---
 rescue/rescue.c | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/rescue/rescue.c b/rescue/rescue.c
index 9a7c988..8180ba0 100644
--- a/rescue/rescue.c
+++ b/rescue/rescue.c
@@ -451,11 +451,14 @@ do_suggestion (struct drv *drvs)
     for (j = 0; mps[j] != NULL; j += 2)
       printf ("mount %s /sysroot%s\n", mps[j+1], mps[j]);
 
     /* If it's Linux, print the bind-mounts. */
     if (type && STREQ (type, "linux")) {
       printf ("mount --rbind /dev /sysroot/dev\n");
       printf ("mount --rbind /proc /sysroot/proc\n");
       printf ("mount --rbind /sys /sysroot/sys\n");
+      printf ("\n");
+      printf ("cd /sysroot\n");
+      printf ("chroot /sysroot\n");
     }
 
     printf ("\n");
@@ -451,11 +451,14 @@ do_suggestion (struct drv *drvs)
       printf ("mount %s /sysroot%s\n", mps[j+1], mps[j]);
 
-    /* If it's Linux, print the bind-mounts. */
+    /* If it's Linux, print the bind-mounts and a chroot command. */
     if (type && STREQ (type, "linux")) {
       printf ("mount --rbind /dev /sysroot/dev\n");
-- 
2.7.4




More information about the Libguestfs mailing list